var Lint = require("./lint");
var path = require("path");
var configuration_1 = require("./configuration");
var moduleDirectory = path.dirname(module.filename);
var Linter = (function () {
    function Linter(fileName, source, options) {
        this.fileName = fileName;
        this.source = source;
        this.options = options;
    }
    Linter.prototype.lint = function () {
        var failures = [];
        var sourceFile = Lint.getSourceFile(this.fileName, this.source);
        var rulesWalker = new Lint.EnableDisableRulesWalker(sourceFile, {
            disabledIntervals: [],
            ruleName: ""
        });
        rulesWalker.walk(sourceFile);
        var enableDisableRuleMap = rulesWalker.enableDisableRuleMap;
        var rulesDirectory = this.getRelativePath(this.options.rulesDirectory);
        var configuration = this.options.configuration.rules;
        var configuredRules = Lint.loadRules(configuration, enableDisableRuleMap, rulesDirectory);
        for (var _i = 0; _i < configuredRules.length; _i++) {
            var rule = configuredRules[_i];
            if (rule.isEnabled()) {
                var ruleFailures = rule.apply(sourceFile);
                for (var _a = 0; _a < ruleFailures.length; _a++) {
                    var ruleFailure = ruleFailures[_a];
                    if (!this.containsRule(failures, ruleFailure)) {
                        failures.push(ruleFailure);
                    }
                }
            }
        }
        var formatter;
        var formattersDirectory = this.getRelativePath(this.options.formattersDirectory);
        var Formatter = Lint.findFormatter(this.options.formatter, formattersDirectory);
        if (Formatter) {
            formatter = new Formatter();
        }
        else {
            throw new Error("formatter '" + this.options.formatter + "' not found");
        }
        var output = formatter.format(failures);
        return {
            failureCount: failures.length,
            failures: failures,
            format: this.options.formatter,
            output: output
        };
    };
    Linter.prototype.getRelativePath = function (directory) {
        if (directory) {
            return path.relative(moduleDirectory, directory);
        }
        return undefined;
    };
    Linter.prototype.containsRule = function (rules, rule) {
        return rules.some(function (r) { return r.equals(rule); });
    };
    Linter.VERSION = "3.0.0-dev.1";
    Linter.findConfiguration = configuration_1.findConfiguration;
    return Linter;
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = Linter;
